from fastapi import WebSocket


class WebSocketManager:
    def __init__(self):
        self.active_socket: dict[str, WebSocket] = {}

    async def connect(self, id: str, websocket: WebSocket):
        await websocket.accept()
        self.active_socket[id] = websocket

    def disconnect(self, user_id: str):
        del self.active_socket[user_id]

    async def send_to_another(self, another: str, msg: dict):
        socket = self.active_socket.get(another)
        await socket.send_json(msg)

    async def broadcast(self, msg: dict, receiver_ids: list[str]):
        for receiver_id in receiver_ids:
            socket = self.active_socket.get(receiver_id)
            if socket:
                await socket.send_json(msg)
